Module assembler

Module assembler 

Modules

lower
parser
tokens

Functions

assemble
This function is used to convert a string of Tsar code directly to the Xasm intermediate representation.
format_error
This is used to take an LALRPOP error and convert it into a nicely formatted error message
make_error
This formats an error properly given the line, the unexpected token as a string, the line number, and the column number of the unexpected token.